coherence.upnp.services.clients.content_directory_client (module) — Cohen3 0.8.0 documentation

# coherence.upnp.services.clients.content_directory_client (module)

class `ContentDirectoryClient`(service)

  Bases: `object`

  `remove`()
  `subscribe_for_variable`(var_name, callback, signal=False)
  `get_search_capabilities`()
  `get_sort_extension_capabilities`()
  `get_feature_list`()
  `get_system_update_id`()
  `browse`(object_id=0, browse_flag='BrowseDirectChildren', filter='*', sort_criteria='', starting_index=0, requested_count=0, process_result=True, backward_compatibility=False)
  `search`(container_id, criteria, starting_index=0, requested_count=0)
  `dict2item`(elements)
  `create_object`(container_id, elements)
  `destroy_object`(object_id)
  `update_object`(object_id, current_tag_value, new_tag_value)
  `move_object`(object_id, new_parent_id)
  `import_resource`(source_uri, destination_uri)
  `export_resource`(source_uri, destination_uri)
  `delete_resource`(resource_uri)
  `stop_transfer_resource`(transfer_id)
  `get_transfer_progress`(transfer_id)
  `create_reference`(container_id, object_id)
  `_failure`(error)